@@ -24,6 +24,10 @@ import sqlite3
 import parser
 import tkcalendar
 
+def Print(val):
+    print(val)
+
+
 class Make():
     def Life_Calculator():
         root = Tk()
@@ -653,7 +657,7 @@ class HandProjects():
         cap.set(4,720)
 
         xp, yp = 0,0
-        detector = htm.handDetector(detectionCon=Confidence)
+        detector = htm1.handDetector(detectionCon=Confidence)
 
         brushThickness = BrushThickness
         eraserThickness = EraserThickness
